@@ -104,14 +104,14 @@ class BaseHandler(BaseHandler):
                     ret.active = True
                     ret.token = self.current_user.token
                     keys = ['active', 'openId', 'avatarUrl', 'city', 'country', 'gender', 'language', 'nickName', 'province']
-                    update = {k: v for k, v in ret.items() if k in keys}
+                    update = {k: v for k, v in ret.items() if k in keys if v}
                     await awaitable(self.db.users.update_one({'_id': self.current_user._id}, {'$set': update}))
                 else:
                     ret.id = await awaitable(self.db.users.seq_id)
                     ret.token = uuid.uuid4().hex
                     ret.active = True
                     ret.created_at = datetime.datetime.now().replace(microsecond=0)
-                    await awaitable(self.db.users.insert_one(ret))
+                    await awaitable(self.db.users.update_one({'openId': ret.openId}, {'$set': ret}, upsert=True))
             expires = datetime.datetime.now() + datetime.timedelta(days=30)
             self.set_cookie('token', ret.token, expires=expires)
             ret.err = 0
