@@ -32,39 +32,6 @@ from rich.table import Table
 from tqdm import tqdm
 
 
-'''
-class Queue(queue.Queue):
-
-    def _init(self, maxsize):
-        self.queue = OrderedSet()
-
-    def _put(self, item):
-        self.queue.add(item)
-
-    def _get(self):
-        return self.queue.pop(last=False)
-
-    def __contains__(self, item):
-        with self.mutex:
-            return item in self.queue
-
-
-class AioQueue(asyncio.Queue):
-
-    def _init(self, maxsize):
-        self._queue = OrderedSet()
-
-    def _put(self, item):
-        self._queue.add(item)
-
-    def _get(self):
-        return self._queue.pop(last=False)
-
-    def __contains__(self, item):
-        return item in self.queue
-'''
-
-
 def _include_yaml(loader, node):
     root = Path(loader.name).parent
     if isinstance(node, yaml.SequenceNode):
