@@ -9,7 +9,6 @@ import asyncio
 import inspect
 import sys
 
-from .base_utils import pprint
 from .config_utils import Config
 
 
@@ -45,6 +44,3 @@ def Fire(component=None, stdout=True):
     if inspect.isawaitable(ret):
         loop = asyncio.get_event_loop()
         ret = loop.run_until_complete(ret)
-
-    if stdout and ret is not None:
-        pprint(ret)
