@@ -85,7 +85,7 @@ class ChunkedMultipartEncoderMonitor(MultipartEncoderMonitor):
 
 class Response:
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, decode_body=False, **kwargs):
         if args and isinstance(args[0], HTTPResponse):
             self.url = args[0].effective_url
             self.time = args[0].request_time
@@ -107,6 +107,9 @@ class Response:
         elif not hasattr(self, 'headers'):
             self.headers = CaseInsensitiveDict()
 
+        if decode_body:
+            self.body = self._decompress(self.headers, self.body)
+
     @staticmethod
     def _decompress_gzip(body):
         gz = gzip.GzipFile(fileobj=io.BytesIO(body), mode='rb')
